@@ -10,20 +10,20 @@ use base 'Perl::Critic::Policy';
 
 use Readonly;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 Readonly::Scalar my $DESC => q{Use of "open" is not allowed};
 Readonly::Scalar my $EXPL => q{Use file operation methods of MainObject instead.};
 
 sub supported_parameters { return; }
 sub default_severity     { return $SEVERITY_HIGHEST; }
-sub default_themes       { return qw( otrs ) }
+sub default_themes       { return qw( otrs otrs_lt_3_3 ) }
 sub applies_to           { return 'PPI::Token::Word'  }
 
 sub violates {
     my ( $self, $elem ) = @_;
 
-    return if $elem ne 'open';
+    return if $elem ne 'open' and $elem ne 'CORE::open';
     return $self->violation( $DESC, $EXPL, $elem );
 }
 
@@ -39,7 +39,7 @@ Perl::Critic::Policy::OTRS::ProhibitOpen - Do not use "open"
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 AUTHOR
 
