@@ -10,14 +10,14 @@ use base 'Perl::Critic::Policy';
 
 use Readonly;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 Readonly::Scalar my $DESC => q{Use of "print", "die", and "exit" in modules is not allowed};
 Readonly::Scalar my $EXPL => q{Use methods of LayoutObject or MainObject instead.};
 
 sub supported_parameters { return; }
 sub default_severity     { return $SEVERITY_HIGHEST; }
-sub default_themes       { return qw( otrs ) }
+sub default_themes       { return qw( otrs otrs_lt_3_3 ) }
 sub applies_to           { return 'PPI::Token::Word' }
 
 my @prohibited = qw(print die exit);
@@ -25,7 +25,7 @@ my @prohibited = qw(print die exit);
 sub violates {
     my ( $self, $elem ) = @_;
 
-    return if !grep{ $elem eq $_ }@prohibited;
+    return if !grep{ $elem eq $_ || $elem eq 'CORE::' . $_ }@prohibited;
     return if $self->_is_script( $elem );
     return $self->violation( $DESC, $EXPL, $elem );
 }
@@ -42,6 +42,9 @@ sub _is_script {
     # For now, only run this for controller modules (Kernel/Modules/*, Kernel/Output/HTML/)
     $is_module &&= $filename =~ m{ Kernel/Modules }xms;
 
+    # this is for the test modules
+    $is_module = $filename =~ m{ (^|/)t/Module }xms;
+
     return !$is_module;
 }
 
@@ -57,7 +60,7 @@ Perl::Critic::Policy::OTRS::ProhibitSomeCoreFunctions - Some core functions shou
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 AUTHOR
 
